<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Tue Apr 28 2020 14:15:38 GMT+0000 (Coordinated Universal Time)


## Refactor
  - Refactored base render function to use write instead of finish, resolves a performance issue
  ([fafc42aa](https://gitlab-ci-token:JMJZtYjB4PXJVVxxmaLP@git.sickrage.ca/SiCKRAGE/sickrage/commit/fafc42aa13ea71e31831e68a71391e66eed1995d))




